==> kubernetes-model-gatewayapi-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GRPCRouteFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GRPCRouteFluentImpl<A extends GRPCRouteFluent<A>> extends BaseFluent<A> implements GRPCRouteFluent<A>{
  public GRPCRouteFluentImpl() {
  }
  public GRPCRouteFluentImpl(GRPCRoute instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private GRPCRouteSpecBuilder spec;
  private GRPCRouteStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public GRPCRouteFluent.MetadataNested<A> withNewMetadata() {
    return new GRPCRouteFluentImpl.MetadataNestedImpl();
  }
  public GRPCRouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new GRPCRouteFluentImpl.MetadataNestedImpl(item);
  }
  public GRPCRouteFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public GRPCRouteFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public GRPCRouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GRPCRouteSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public GRPCRouteSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(GRPCRouteSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new GRPCRouteSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public GRPCRouteFluent.SpecNested<A> withNewSpec() {
    return new GRPCRouteFluentImpl.SpecNestedImpl();
  }
  public GRPCRouteFluent.SpecNested<A> withNewSpecLike(GRPCRouteSpec item) {
    return new GRPCRouteFluentImpl.SpecNestedImpl(item);
  }
  public GRPCRouteFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public GRPCRouteFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new GRPCRouteSpecBuilder().build());
  }
  public GRPCRouteFluent.SpecNested<A> editOrNewSpecLike(GRPCRouteSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GRPCRouteStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public GRPCRouteStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(GRPCRouteStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new GRPCRouteStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public GRPCRouteFluent.StatusNested<A> withNewStatus() {
    return new GRPCRouteFluentImpl.StatusNestedImpl();
  }
  public GRPCRouteFluent.StatusNested<A> withNewStatusLike(GRPCRouteStatus item) {
    return new GRPCRouteFluentImpl.StatusNestedImpl(item);
  }
  public GRPCRouteFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public GRPCRouteFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new GRPCRouteStatusBuilder().build());
  }
  public GRPCRouteFluent.StatusNested<A> editOrNewStatusLike(GRPCRouteStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GRPCRouteFluentImpl that = (GRPCRouteFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<GRPCRouteFluent.MetadataNested<N>> implements GRPCRouteFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) GRPCRouteFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends GRPCRouteSpecFluentImpl<GRPCRouteFluent.SpecNested<N>> implements GRPCRouteFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(GRPCRouteSpec item) {
      this.builder = new GRPCRouteSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new GRPCRouteSpecBuilder(this);
    }
    GRPCRouteSpecBuilder builder;
    public N and() {
      return (N) GRPCRouteFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends GRPCRouteStatusFluentImpl<GRPCRouteFluent.StatusNested<N>> implements GRPCRouteFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(GRPCRouteStatus item) {
      this.builder = new GRPCRouteStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new GRPCRouteStatusBuilder(this);
    }
    GRPCRouteStatusBuilder builder;
    public N and() {
      return (N) GRPCRouteFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GRPCRouteFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GRPCRouteFluentImpl<A extends GRPCRouteFluent<A>> extends BaseFluent<A> implements GRPCRouteFluent<A>{
  public GRPCRouteFluentImpl() {
  }
  public GRPCRouteFluentImpl(GRPCRoute instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private GRPCRouteSpecBuilder spec;
  private GRPCRouteStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public GRPCRouteFluentImpl.MetadataNested<A> withNewMetadata() {
    return new GRPCRouteFluentImpl.MetadataNestedImpl();
  }
  public GRPCRouteFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new GRPCRouteFluentImpl.MetadataNestedImpl(item);
  }
  public GRPCRouteFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public GRPCRouteFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public GRPCRouteFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GRPCRouteSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public GRPCRouteSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(GRPCRouteSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new GRPCRouteSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public GRPCRouteFluentImpl.SpecNested<A> withNewSpec() {
    return new GRPCRouteFluentImpl.SpecNestedImpl();
  }
  public GRPCRouteFluentImpl.SpecNested<A> withNewSpecLike(GRPCRouteSpec item) {
    return new GRPCRouteFluentImpl.SpecNestedImpl(item);
  }
  public GRPCRouteFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public GRPCRouteFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new GRPCRouteSpecBuilder().build());
  }
  public GRPCRouteFluentImpl.SpecNested<A> editOrNewSpecLike(GRPCRouteSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GRPCRouteStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public GRPCRouteStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(GRPCRouteStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new GRPCRouteStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public GRPCRouteFluentImpl.StatusNested<A> withNewStatus() {
    return new GRPCRouteFluentImpl.StatusNestedImpl();
  }
  public GRPCRouteFluentImpl.StatusNested<A> withNewStatusLike(GRPCRouteStatus item) {
    return new GRPCRouteFluentImpl.StatusNestedImpl(item);
  }
  public GRPCRouteFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public GRPCRouteFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new GRPCRouteStatusBuilder().build());
  }
  public GRPCRouteFluentImpl.StatusNested<A> editOrNewStatusLike(GRPCRouteStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GRPCRouteFluentImpl that = (GRPCRouteFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<GRPCRouteFluentImpl.MetadataNested<N>> implements GRPCRouteFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) GRPCRouteFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends GRPCRouteSpecFluentImpl<GRPCRouteFluentImpl.SpecNested<N>> implements GRPCRouteFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(GRPCRouteSpec item) {
      this.builder = new GRPCRouteSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new GRPCRouteSpecBuilder(this);
    }
    GRPCRouteSpecBuilder builder;
    public N and() {
      return (N) GRPCRouteFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends GRPCRouteStatusFluentImpl<GRPCRouteFluentImpl.StatusNested<N>> implements GRPCRouteFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(GRPCRouteStatus item) {
      this.builder = new GRPCRouteStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new GRPCRouteStatusBuilder(this);
    }
    GRPCRouteStatusBuilder builder;
    public N and() {
      return (N) GRPCRouteFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
